@@ -13,6 +13,8 @@ plot(anemones, markscale=1)
 
 ants.extra$plotit()
 
+plot(austates)
+
 plot(bei.extra$elev, main="Beilschmiedia")
 plot(bei, add=TRUE, pch=16, cex=0.3)
 
@@ -23,6 +25,9 @@ plot(split(bramblecanes))
 
 plot(bronzefilter,markscale=2)
 
+plot(subset(btb, select=spoligotype), cols=2:5,
+     main="Bovine Tuberculosis, by spoligotype")
+
 plot(cells)
 
 plot(chicago, main="Chicago Street Crimes", col="grey",
@@ -35,12 +40,16 @@ plot(clmfires, which.marks="cause", cols=2:5, cex=0.25,
      main="Castilla-La Mancha forest fires")
 plot(clmfires.extra$clmcov200, main="Covariates for forest fires")
 
+plot(concrete)
+
 plot(copper$Points, main="Copper")
 plot(copper$Lines, add=TRUE)
 
 plot(demohyper, quote({ plot(Image, main=""); plot(Points, add=TRUE) }),
       parargs=list(mar=rep(1,4)))
 
+plot(dendrite, leg.side="bottom", main="Dendritic spines", cex=0.75, cols=2:4)
+
 plot(demopat)
 
 plot(finpines, main="Finnish pines")
@@ -60,7 +69,7 @@ plot(heather)
 
 plot(humberside)
 
-plot(hyytiala, add=TRUE, cols=2:5)
+plot(hyytiala, cols=2:5)
 
 plot(japanesepines)
 
@@ -88,10 +97,7 @@ plot(split(nbfires)$"2000", which.marks="fire.type",
 plot(nztrees)
 plot(trim.rectangle(as.owin(nztrees), c(0,5), 0), add=TRUE, lty=3)
 
-enable3d <- ("scatterplot3d" %in% row.names(installed.packages()))
-if(enable3d) {
-  plot(osteo[1:10,], tick.marks=FALSE, xlab="", ylab="", zlab="")
-}
+plot(osteo[1:10,], tick.marks=FALSE, xlab="", ylab="", zlab="")
 
 plot(paracou, cols=2:3, chars=c(16,3))
 
@@ -103,6 +109,7 @@ plot(pyr, quote(plot(Neurons, pch=16, main=grp)), main="Pyramidal Neurons")
 rm(pyr)
 
 plot(redwood)
+plot(redwood3, add=TRUE, pch=20)
 
 redwoodfull.extra$plotit()
 
@@ -115,15 +122,27 @@ shapley.extra$plotit(main="Shapley")
 
 plot(simdat)
 
+plot(spiders, pch=16, show.window=FALSE)
+
+plot(sporophores, chars=c(16,1,2), cex=0.6)
+points(0,0,pch=16, cex=2)
+text(15,8,"Tree", cex=0.75)
+
 plot(spruces, maxsize=min(nndist(spruces)))
 
+plot(subset(stonetools, select=TYPE),
+     main="Palaeolithic stone tools and bone fragments",
+     cols=2:3, cex=0.5)
+
 plot(swedishpines)
 
 plot(urkiola, cex=0.5, cols=2:3)
 
 plot(waka, markscale=0.04, main=c("Waka national park", "tree diameters"))
 
-plot(waterstriders)
+plot(waterstriders, main.panel="",
+     equal.scales=TRUE, mar.panel=0, hsep=1,
+     cex=0.75)
 
 par(oldpar)
 options(oldoptions)
