@@ -1,7 +1,7 @@
 ### R code from vignette source 'updates.Rnw'
 
 ###################################################
-### code chunk number 1: updates.Rnw:22-28
+### code chunk number 1: updates.Rnw:20-26
 ###################################################
 library(spatstat)
 x <- read.dcf(file = system.file("DESCRIPTION", package = "spatstat"),
@@ -12,7 +12,7 @@ options(useFancyQuotes=FALSE)
 
 
 ###################################################
-### code chunk number 2: updates.Rnw:38-125
+### code chunk number 2: updates.Rnw:36-140
 ###################################################
 readSizeTable <- function(fname) {
   if(is.null(fname) || !file.exists(fname)) return(NULL)
@@ -21,8 +21,13 @@ readSizeTable <- function(fname) {
   return(a)
 }
 getSizeTable <- function(packagename="spatstat", tablename="packagesizes.txt") {
-  fname <- system.file("doc", tablename, package=packagename)
-  readSizeTable(fname)
+  fname <- system.file("info", tablename, package=packagename)
+  out <- readSizeTable(fname)
+  if(is.null(out)) {
+    fname <- system.file("doc", tablename, package=packagename)
+    out <- readSizeTable(fname)
+  }
+  return(out)
 }
 RemoveDevel <- function(sizetable) {
   ## remove entries with fractional version numbers
@@ -66,32 +71,44 @@ mergeSizeTables <- function(a, b, breakupdate, allow.devel=FALSE) {
   }
   return(result)
 }
-## start collating size tables for the spatstat family
-z <- getSizeTable()
-## sub-packages- access via the sub-package
-zgeom <- getSizeTable("spatstat.geom")
-zcore <- getSizeTable("spatstat.core")
-zlin <- getSizeTable("spatstat.linnet")
-zutils <- getSizeTable("spatstat.utils")
-zdata <- getSizeTable("spatstat.data")
-zsparse <- getSizeTable("spatstat.sparse")
-## merge history of geom, core, linnet after the big split
-Bday <- "2020-12-14"
-z <- mergeSizeTables(z, zgeom, Bday)
-z <- mergeSizeTables(z, zcore, Bday)
-z <- mergeSizeTables(z, zlin, Bday)
-## merge history of other packages after their split dates
-z <- mergeSizeTables(z, zutils, "2017-03-22")
-z <- mergeSizeTables(z, zdata,  "2017-09-23")
+## Get histories of all sub-packages
+## Package formerly known as 'spatstat'
+z <- getSizeTable() 
+## installed sub-packages - access via the installed sub-packages
+zutils   <- getSizeTable("spatstat.utils")
+zdata    <- getSizeTable("spatstat.data")
+zunivar  <- getSizeTable("spatstat.univar")
+zsparse  <- getSizeTable("spatstat.sparse")
+zgeom    <- getSizeTable("spatstat.geom")
+zrandom  <- getSizeTable("spatstat.random")
+zexplore <- getSizeTable("spatstat.explore")
+zmodel   <- getSizeTable("spatstat.model")
+zlinnet  <- getSizeTable("spatstat.linnet")
+## other sub-packages - access via stored copies of package size files
+##       defunct package spatstat.core 
+zcore    <- getSizeTable("spatstat", "spatstatcoresize.txt")
+##       extension packages 
+zlocal   <- getSizeTable("spatstat", "spatstatlocalsize.txt")
+zgui     <- getSizeTable("spatstat", "spatstatguisize.txt")
+zKnet    <- getSizeTable("spatstat", "spatstatKnetsize.txt")
+## Merge histories starting at the 'split dates'
+z <- mergeSizeTables(z, zutils,  "2017-03-22")
+z <- mergeSizeTables(z, zdata,   "2017-09-23")
 z <- mergeSizeTables(z, zsparse, "2020-11-04")
-## extension packages - use copy of package size file stored in spatstat
-zlocal <- getSizeTable("spatstat", "spatstatlocalsize.txt")
-zgui <- getSizeTable("spatstat", "spatstatguisize.txt")
-zKnet <- getSizeTable("spatstat", "spatstatKnetsize.txt")
+BigSplitDay <- "2020-12-14"
+z <- mergeSizeTables(z, zgeom,   BigSplitDay)
+z <- mergeSizeTables(z, zcore,   BigSplitDay)
+z <- mergeSizeTables(z, zlinnet, BigSplitDay)
+z <- mergeSizeTables(z, zrandom, "2022-02-12")
+CoreSplitDay <- "2020-05-25"   # size of 'core' drops to 0 on this date
+z <- mergeSizeTables(z, zexplore, CoreSplitDay)
+z <- mergeSizeTables(z, zmodel,   CoreSplitDay)
+z <- mergeSizeTables(z, zunivar,  "2024-04-21")
+## extension packages: these never overlapped spatstat
 z <- mergeSizeTables(z, zlocal)
 z <- mergeSizeTables(z, zgui)
 z <- mergeSizeTables(z, zKnet)
-#
+## Now summarise
 currentcount <- z[nrow(z), counts]
 bookcount    <- z[z$version == "1.42-0", counts]
 changes <- currentcount - bookcount
@@ -104,7 +121,7 @@ growth <- signif((100 * newcode)/bookcode, digits=2)
 
 
 ###################################################
-### code chunk number 3: updates.Rnw:137-142
+### code chunk number 3: updates.Rnw:152-157
 ###################################################
 options(SweaveHooks=list(fig=function() par(mar=0.2+c(2,4,2,0))))
 Plot <- function(fmla, ..., dat=z) {
@@ -114,7 +131,7 @@ Plot <- function(fmla, ..., dat=z) {
 
 
 ###################################################
-### code chunk number 4: updates.Rnw:148-153
+### code chunk number 4: updates.Rnw:163-168
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 Plot((Rlines + srclines)/1000 ~ date, ylab="Lines of code (x 1000)", 
@@ -125,7 +142,7 @@ text(as.Date("2015-01-01"), 60, "R code")
 
 
 ###################################################
-### code chunk number 5: updates.Rnw:170-188
+### code chunk number 5: updates.Rnw:185-209
 ###################################################
 ## Tabulate latest version numbers of packages
 vtable <- data.frame(package="spatstat", version=sversion, date=as.Date(sdate))
@@ -136,19 +153,25 @@ AppendVersion <- function(pkg, sizetable, v, allow.devel=FALSE) {
   if(is.null(lastrow)) return(v)
   rbind(v, data.frame(package=pkg, version=lastrow[,"version"], date=as.Date(lastrow[,"date"])))
 }
-vtable <- AppendVersion("spatstat.geom", zgeom, vtable)
-vtable <- AppendVersion("spatstat.core", zcore, vtable)
-vtable <- AppendVersion("spatstat.linnet", zlin, vtable)
-vtable <- AppendVersion("spatstat.sparse", zsparse, vtable)
-vtable <- AppendVersion("spatstat.data", zdata, vtable)
 vtable <- AppendVersion("spatstat.utils", zutils, vtable)
+vtable <- AppendVersion("spatstat.data", zdata, vtable)
+vtable <- AppendVersion("spatstat.sparse", zsparse, vtable)
+vtable <- AppendVersion("spatstat.univar", zunivar, vtable)
+vtable <- AppendVersion("spatstat.geom", zgeom, vtable)
+vtable <- AppendVersion("spatstat.random", zrandom, vtable)
+vtable <- AppendVersion("spatstat.explore", zexplore, vtable)
+vtable <- AppendVersion("spatstat.model", zmodel, vtable)
+vtable <- AppendVersion("spatstat.linnet", zlinnet, vtable)
+## move spatstat to the bottom
+vtable <- rbind(vtable[-1, ], vtable[1, ])
+## add extras
 vtable <- AppendVersion("spatstat.local", zlocal, vtable)
 vtable <- AppendVersion("spatstat.Knet", zKnet, vtable)
 vtable <- AppendVersion("spatstat.gui", zgui, vtable)
 
 
 ###################################################
-### code chunk number 6: updates.Rnw:194-195
+### code chunk number 6: updates.Rnw:215-216
 ###################################################
 print(vtable[,c(3,1,2)], row.names=FALSE)
 
